@@ -12,9 +12,11 @@
 """
 
 import logging
+import os
+from collections import defaultdict
 from concurrent.futures import FIRST_EXCEPTION, ThreadPoolExecutor, wait
 from itertools import repeat, zip_longest
-from typing import Any, Callable, Iterable, Iterator, Optional, Tuple, TypeVar
+from typing import Any, Callable, DefaultDict, Iterable, Iterator, Optional, Tuple, TypeVar
 from urllib.parse import urljoin
 
 from requests import Session
@@ -23,42 +25,32 @@ from requests.exceptions import RequestException
 from requests.models import PreparedRequest, Response
 from urllib3.util.retry import Retry
 
+from ..__verison__ import __version__
 from .exceptions import GASResponseError
 from .log import RequestLogging, ResponseLogging
 
 logger = logging.getLogger(__name__)
 
 
-# def logging_hook(
-#     response: Response, *args: Any, **kwargs: Any  # pylint: disable=unused-argument
-# ) -> None:
-#     """log the response"""
-#     data = dump.dump_all(response)
-#     logging.debug(data.decode("utf-8"))
-
-
 class Config:  # pylint: disable=too-few-public-methods
-    """This is a base class defining the concept of Post Config.
+    """This is a base class defining the concept of Request Config."""
 
-    Arguments:
-        max_retries: Maximum retry times of the post request.
-        timeout: Timeout value of the post request in seconds.
-        is_intern: Whether the post request is from intern.
+    def __init__(self) -> None:
 
-    """
+        self.max_retries = 3
+        self.allowed_retry_methods = ["HEAD", "OPTIONS", "POST", "PUT"]
+        self.allowed_retry_status = [429, 500, 502, 503, 504]
 
-    def __init__(self, max_retries: int = 3, timeout: int = 15, is_intern: bool = False) -> None:
-
-        self.max_retries = max_retries
-        self.timeout = timeout
-        self._is_intern = is_intern
+        self.timeout = 30
+        self._is_intern = False
+        self._x_source = "PYTHON-SDK"
 
     @property
     def is_intern(self) -> bool:
-        """Get whether the post request is from intern.
+        """Get whether the request is from intern.
 
         Returns:
-            Whether the post request is from intern.
+            Whether the request is from intern.
 
         """
         return self._is_intern
@@ -119,8 +111,8 @@ class UserSession(Session):  # pylint: disable=too-few-public-methods
 
         retry_strategy = Retry(
             total=default_config.max_retries,
-            status_forcelist=[429, 500, 502, 503, 504],
-            method_whitelist=["HEAD", "OPTIONS", "POST", "PUT"],
+            status_forcelist=default_config.allowed_retry_status,
+            method_whitelist=default_config.allowed_retry_methods,
             raise_on_status=False,
         )
 
@@ -188,10 +180,13 @@ class Client:
         else:
             raise TypeError("Wrong accesskey format!")
 
-        self.gateway_url = urljoin(url, "gateway/")
+        if not url.startswith("https://"):
+            raise TypeError("Invalid url, only support url starts with 'https://'")
+
+        self.gateway_url = urljoin(url, "gatewayv2/")
         self.access_key = access_key
 
-        self.session = UserSession()
+        self._sessions: DefaultDict[int, UserSession] = defaultdict(UserSession)
         self._open_api = urljoin(self.gateway_url, "tensorbay-open-api/v1/")
 
     def _url_make(self, section: str, dataset_id: str = "") -> str:
@@ -215,6 +210,15 @@ class Client:
             url = urljoin(self._open_api, "datasets")
         return url
 
+    @property
+    def session(self) -> UserSession:
+        """Create and return a session per PID so each sub-processes will use their own session.
+
+        Returns:
+            The session corresponding to the process.
+        """
+        return self._sessions[os.getpid()]
+
     def open_api_do(
         self, method: str, section: str, dataset_id: str = "", **kwargs: Any
     ) -> Response:
@@ -231,7 +235,9 @@ class Client:
 
         """
         kwargs.setdefault("headers", {})["X-Token"] = self.access_key
-        kwargs["headers"]["X-Source"] = "PYTHON-SDK"
+        kwargs["headers"][
+            "X-Source"
+        ] = f"{default_config._x_source}/{__version__}"  # pylint: disable=protected-access
 
         return self.do(method=method, url=self._url_make(section, dataset_id), **kwargs)
 
