@@ -32,11 +32,11 @@ from itertools import islice
 from typing import TYPE_CHECKING, Any, Dict, Iterable, Iterator, Optional, Tuple, Union
 
 import filetype
-import ulid
 from requests_toolbelt import MultipartEncoder
+from ulid import from_timestamp
 
 from ..dataset import Data, Frame, RemoteData
-from ..sensor.sensor import Sensor
+from ..sensor.sensor import Sensor, Sensors
 from .commit_status import CommitStatus
 from .exceptions import GASException, GASPathError
 from .requests import default_config, paging_range
@@ -434,11 +434,11 @@ class FusionSegmentClient(SegmentClientBase):
             if response["recordSize"] + response["offset"] >= response["totalCount"]:
                 break
 
-    def list_sensors(self) -> Iterator["Sensor._Type"]:
-        """List required sensor object in a segment client.
+    def get_sensors(self) -> Sensors:
+        """Return the sensors in a fusion segment client.
 
-        Yields:
-            Required sensor objects.
+        Returns:
+            The :class:`sensors<~tensorbay.sensor.sensor.Sensors>` in the fusion segment client.
 
         """
         params: Dict[str, Any] = {"segmentName": self._name}
@@ -448,8 +448,7 @@ class FusionSegmentClient(SegmentClientBase):
             "GET", "sensors", self._dataset_id, params=params
         ).json()
 
-        for sensor_info in response["sensors"]:
-            yield Sensor.loads(sensor_info)
+        return Sensors.loads(response["sensors"])
 
     def upload_sensor(self, sensor: Sensor) -> None:
         """Upload sensor to the draft.
@@ -503,10 +502,10 @@ class FusionSegmentClient(SegmentClientBase):
                     "Lack frame id, please add frame id in frame or "
                     "give timestamp to the function!"
                 ) from error
-        elif hasattr(frame, "frame_id"):
-            raise TypeError("Frame id conflicts, please do not give timestamp to the function!.")
+        elif not hasattr(frame, "frame_id"):
+            frame_id = from_timestamp(timestamp)
         else:
-            frame_id = str(ulid.from_timestamp(timestamp))
+            raise TypeError("Frame id conflicts, please do not give timestamp to the function!.")
 
         for sensor_name, data in frame.items():
             if not isinstance(data, Data):
@@ -541,7 +540,7 @@ class FusionSegmentClient(SegmentClientBase):
                 frame_info: Dict[str, Any] = {
                     "segmentName": self._name,
                     "sensorName": sensor_name,
-                    "frameId": frame_id,
+                    "frameId": str(frame_id),
                 }
                 if hasattr(data, "timestamp"):
                     frame_info["timestamp"] = data.timestamp
