@@ -27,7 +27,7 @@ from typing import Dict, Iterator, Optional, Sequence, Tuple, Type, TypeVar
 import numpy as np
 
 from ..geometry import Vector2D
-from ..utility import ReprMixin, ReprType, common_loads
+from ..utility import MatrixType, ReprMixin, ReprType, common_loads
 
 
 class CameraMatrix(ReprMixin):
@@ -37,8 +37,14 @@ class CameraMatrix(ReprMixin):
     to 2D points in an image.
 
     Arguments:
+        fx: The x axis focal length expressed in pixels.
+        fy: The y axis focal length expressed in pixels.
+        cx: The x coordinate of the so called principal point that should be in the center of
+            the image.
+        cy: The y coordinate of the so called principal point that should be in the center of
+            the image.
+        skew: It causes shear distortion in the projected image.
         matrix: A 3x3 Sequence of camera matrix.
-        **kwargs: Float values with keys: "fx", "fy", "cx", "cy" and "skew"(optional).
 
     Attributes:
         fx: The x axis focal length expressed in pixels.
@@ -53,6 +59,37 @@ class CameraMatrix(ReprMixin):
         TypeError: When only keyword arguments with incorrect keys are provided,
             or when no arguments are provided.
 
+    Examples:
+        >>> matrix = [[1, 3, 3],
+        ...           [0, 2, 4],
+        ...           [0, 0, 1]]
+
+        *Initialazation Method 1*: Init from 3x3 sequence array.
+
+        >>> camera_matrix = CameraMatrix(matrix=matrix)
+        >>> camera_matrix
+        CameraMatrix(
+            (fx): 1,
+            (fy): 2,
+            (cx): 3,
+            (cy): 4,
+            (skew): 3
+        )
+
+        *Initialazation Method 2*: Init from camera calibration parameters, skew is optional.
+
+        >>> camera_matrix = CameraMatrix(fx=1, fy=2, cx=3, cy=4, skew=3)
+        >>> camera_matrix
+        CameraMatrix(
+            (fx): 1,
+            (fy): 2,
+            (cx): 3,
+            (cy): 4,
+            (skew): 3
+        )
+
+
+
     """
 
     _T = TypeVar("_T", bound="CameraMatrix")
@@ -60,30 +97,36 @@ class CameraMatrix(ReprMixin):
     _repr_type = ReprType.INSTANCE
     _repr_attrs = ("fx", "fy", "cx", "cy", "skew")
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
-        matrix: Optional[Sequence[Sequence[float]]] = None,
-        **kwargs: float,
+        fx: Optional[float] = None,
+        fy: Optional[float] = None,
+        cx: Optional[float] = None,
+        cy: Optional[float] = None,
+        skew: float = 0,
+        *,
+        matrix: Optional[MatrixType] = None,
     ) -> None:
-        if kwargs:
-            try:
-                self._loads(kwargs)
-                return
-            except KeyError as error:
-                if matrix is None:
-                    raise TypeError(
-                        f"Missing key {error} in kwargs to initialize {self.__class__.__name__}"
-                    ) from error
-
         if matrix is not None:
-            self.fx = matrix[0][0]  # pylint: disable=invalid-name
-            self.fy = matrix[1][1]  # pylint: disable=invalid-name
-            self.cx = matrix[0][2]  # pylint: disable=invalid-name
-            self.cy = matrix[1][2]  # pylint: disable=invalid-name
-            self.skew = matrix[0][1]
+            # pylint: disable=invalid-name
+            self.fx: float = matrix[0][0]
+            self.fy: float = matrix[1][1]
+            self.cx: float = matrix[0][2]
+            self.cy: float = matrix[1][2]
+            self.skew: float = matrix[0][1]
             return
 
-        raise TypeError(f"Require 'fx', 'fy', 'cx', 'cy' to initialize {self.__class__.__name__}")
+        if not (fx is None or fy is None or cx is None or cy is None):
+            self.fx = fx
+            self.fy = fy
+            self.cx = cx
+            self.cy = cy
+            self.skew = skew
+            return
+
+        raise TypeError(
+            f"Require 'fx', 'fy', 'cx', 'cy' or 3x3 matrix to initialize {self.__class__.__name__}"
+        )
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
@@ -114,6 +157,24 @@ class CameraMatrix(ReprMixin):
         Returns:
             A :class:`CameraMatrix` instance contains the information from the contents dict.
 
+        Examples:
+            >>> contents = {
+            ...     "fx": 2,
+            ...     "fy": 6,
+            ...     "cx": 4,
+            ...     "cy": 7,
+            ...     "skew": 3
+            ... }
+            >>> camera_matrix = CameraMatrix.loads(contents)
+            >>> camera_matrix
+            CameraMatrix(
+                (fx): 2,
+                (fy): 6,
+                (cx): 4,
+                (cy): 7,
+                (skew): 3
+            )
+
         """
         return common_loads(cls, contents)
 
@@ -123,6 +184,10 @@ class CameraMatrix(ReprMixin):
         Returns:
             A dict containing the information of the camera matrix.
 
+        Examples:
+            >>> camera_matrix.dumps()
+            {'fx': 1, 'fy': 2, 'cx': 3, 'cy': 4, 'skew': 3}
+
         """
         return {
             "fx": self.fx,
@@ -138,6 +203,13 @@ class CameraMatrix(ReprMixin):
         Returns:
             A 3x3 numpy array representing the camera matrix.
 
+        Examples:
+            >>> numpy_array = camera_matrix.as_matrix()
+            >>> numpy_array
+            array([[1., 3., 3.],
+                   [0., 4., 4.],
+                   [0., 0., 1.]])
+
         """
         return np.array(
             [
@@ -159,6 +231,17 @@ class CameraMatrix(ReprMixin):
         Raises:
             TypeError: When the dimension of the input point is neither two nor three.
 
+        Examples:
+            Project a point in 2 dimensions
+
+            >>> camera_matrix.project([1, 2])
+            Vector2D(12, 19)
+
+            Project a point in 3 dimensions
+
+            >>> camera_matrix.project([1, 2, 4])
+            Vector2D(6.0, 10.0)
+
         """
         if len(point) == 3:
             x = point[0] / point[2]
@@ -167,7 +250,7 @@ class CameraMatrix(ReprMixin):
             x = point[0]
             y = point[1]
         else:
-            raise TypeError("The point to be projected must have 2 or 3 dimension")
+            raise TypeError("The point to be projected must have 2 or 3 dimensions")
 
         x = self.fx * x + self.skew * y + self.cx
         y = self.fy * y + self.cy
@@ -186,6 +269,16 @@ class DistortionCoefficients(ReprMixin):
     Raises:
         TypeError: When tangential and radial distortion is not provided to initialize class.
 
+    Examples:
+        >>> distortion_coefficients = DistortionCoefficients(p1=1, p2=2, k1=3, k2=4)
+        >>> distortion_coefficients
+        DistortionCoefficients(
+            (p1): 1,
+            (p2): 2,
+            (k1): 3,
+            (k2): 4
+        )
+
     """
 
     _T = TypeVar("_T", bound="DistortionCoefficients")
@@ -292,6 +385,22 @@ class DistortionCoefficients(ReprMixin):
             A :class:`DistortionCoefficients` instance containing information from
             the contents dict.
 
+        Examples:
+            >>> contents = {
+            ...     "p1": 1,
+            ...     "p2": 2,
+            ...     "k1": 3,
+            ...     "k2": 4
+            ... }
+            >>> distortion_coefficients = DistortionCoefficients.loads(contents)
+            >>> distortion_coefficients
+            DistortionCoefficients(
+                (p1): 1,
+                (p2): 2,
+                (k1): 3,
+                (k2): 4
+            )
+
         """
         return common_loads(cls, contents)
 
@@ -301,6 +410,10 @@ class DistortionCoefficients(ReprMixin):
         Returns:
             A dict containing the information of distortion coefficients.
 
+        Examples:
+            >>> distortion_coefficients.dumps()
+            {'p1': 1, 'p2': 2, 'k1': 3, 'k2': 4}
+
         """
         contents = {}
         for distortion_key in self._DISTORTION_KEYS:
@@ -323,6 +436,22 @@ class DistortionCoefficients(ReprMixin):
         Returns:
             Distorted 2d point.
 
+        Examples:
+            Distort a point with 2 dimensions
+
+            >>> distortion_coefficients.distort((1.0, 2.0))
+            Vector2D(134.0, 253.0)
+
+            Distort a point with 3 dimensions
+
+            >>> distortion_coefficients.distort((1.0, 2.0, 3.0))
+            Vector2D(3.3004115226337447, 4.934156378600823)
+
+            Distort a point with 2 dimensions, fisheye is True
+
+            >>> distortion_coefficients.distort((1.0, 2.0), is_fisheye=True)
+            Vector2D(6.158401093771876, 12.316802187543752)
+
         """
         # pylint: disable=invalid-name
         if len(point) == 3:
@@ -332,7 +461,7 @@ class DistortionCoefficients(ReprMixin):
             x = point[0]
             y = point[1]
         else:
-            raise TypeError("The point to be projected must have 2 or 3 dimension")
+            raise TypeError("The point to be projected must have 2 or 3 dimensions")
 
         x2 = x ** 2
         y2 = y ** 2
@@ -353,16 +482,70 @@ class CameraIntrinsics(ReprMixin):
     They describe the mapping of the scene in front of the camera to the pixels in the final image.
 
     Arguments:
+        fx: The x axis focal length expressed in pixels.
+        fy: The y axis focal length expressed in pixels.
+        cx: The x coordinate of the so called principal point that should be in the center of
+            the image.
+        cy: The y coordinate of the so called principal point that should be in the center of
+            the image.
+        skew: It causes shear distortion in the projected image.
         camera_matrix: A 3x3 Sequence of the camera matrix.
-        _init_distortion: Whether init distortion, default is True.
-        **kwargs: Float values to initialize :class:`CameraMatrix` and
-            :class:`DistortionCoefficients`.
+        **kwargs: Float values to initialize :class:`DistortionCoefficients`.
 
     Attributes:
         _camera_matrix: A 3x3 Sequence of the camera matrix.
         _distortion_coefficients: It is the deviation from rectilinear projection. It includes
             radial distortion and tangential distortion.
 
+    Examples:
+        >>> matrix = [[1, 3, 3],
+        ...           [0, 2, 4],
+        ...           [0, 0, 1]]
+
+        *Initialization Method 1*: Init from 3x3 sequence array.
+
+        >>> camera_intrinsics = CameraIntrinsics(camera_matrix=matrix, p1=5, k1=6)
+        >>> camera_intrinsics
+        CameraIntrinsics(
+            (camera_matrix): CameraMatrix(
+                    (fx): 1,
+                    (fy): 2,
+                    (cx): 3,
+                    (cy): 4,
+                    (skew): 3
+                ),
+            (distortion_coefficients): DistortionCoefficients(
+                    (p1): 5,
+                    (k1): 6
+                )
+        )
+
+        *Initialization Method 2*: Init from camera calibration parameters, skew is optional.
+
+        >>> camera_intrinsics = CameraIntrinsics(
+        ...     fx=1,
+        ...     fy=2,
+        ...     cx=3,
+        ...     cy=4,
+        ...     p1=5,
+        ...     k1=6,
+        ...     skew=3
+        ... )
+        >>> camera_intrinsics
+        CameraIntrinsics(
+            (camera_matrix): CameraMatrix(
+                (fx): 1,
+                (fy): 2,
+                (cx): 3,
+                (cy): 4,
+                (skew): 3
+            ),
+            (distortion_coefficients): DistortionCoefficients(
+                (p1): 5,
+                (k1): 6
+            )
+        )
+
     """
 
     _T = TypeVar("_T", bound="CameraIntrinsics")
@@ -371,22 +554,19 @@ class CameraIntrinsics(ReprMixin):
     _repr_attrs = ("camera_matrix", "distortion_coefficients")
     _repr_maxlevel = 2
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
-        camera_matrix: Optional[Sequence[Sequence[float]]] = None,
+        fx: Optional[float] = None,
+        fy: Optional[float] = None,
+        cx: Optional[float] = None,
+        cy: Optional[float] = None,
+        skew: float = 0,
         *,
-        _init_distortion: bool = True,
+        camera_matrix: Optional[MatrixType] = None,
         **kwargs: float,
     ) -> None:
-        self._camera_matrix = CameraMatrix(camera_matrix, **kwargs)
-        self._distortion_coefficients: Optional[DistortionCoefficients]
-        if kwargs and _init_distortion:
-            try:
-                self._distortion_coefficients = DistortionCoefficients.loads(kwargs)
-                return
-            except TypeError:
-                pass
-        self._distortion_coefficients = None
+        self._camera_matrix = CameraMatrix(fx, fy, cx, cy, skew, matrix=camera_matrix)
+        self._distortion_coefficients = DistortionCoefficients.loads(kwargs) if kwargs else None
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
@@ -417,6 +597,39 @@ class CameraIntrinsics(ReprMixin):
             A :class:`CameraIntrinsics` instance containing information from
             the contents dict.
 
+        Examples:
+            >>> contents = {
+            ...     "cameraMatrix": {
+            ...         "fx": 1,
+            ...         "fy": 2,
+            ...         "cx": 3,
+            ...         "cy": 4,
+            ...     },
+            ...     "distortionCoefficients": {
+            ...         "p1": 1,
+            ...         "p2": 2,
+            ...         "k1": 3,
+            ...         "k2": 4
+            ...     },
+            ... }
+            >>> camera_intrinsics = CameraIntrinsics.loads(contents)
+            >>> camera_intrinsics
+            CameraIntrinsics(
+                (camera_matrix): CameraMatrix(
+                    (fx): 1,
+                    (fy): 2,
+                    (cx): 3,
+                    (cy): 4,
+                    (skew): 0
+                ),
+                (distortion_coefficients): DistortionCoefficients(
+                    (p1): 1,
+                    (p2): 2,
+                    (k1): 3,
+                    (k2): 4
+                )
+            )
+
         """
         return common_loads(cls, contents)
 
@@ -427,6 +640,16 @@ class CameraIntrinsics(ReprMixin):
         Returns:
             :class:`CameraMatrix` class object containing fx, fy, cx, cy, skew(optional).
 
+        Examples:
+            >>> camera_intrinsics.camera_matrix
+            CameraMatrix(
+                (fx): 1,
+                (fy): 2,
+                (cx): 3,
+                (cy): 4,
+                (skew): 3
+            )
+
         """
         return self._camera_matrix
 
@@ -438,6 +661,13 @@ class CameraIntrinsics(ReprMixin):
             :class:`DistortionCoefficients` class object containing tangential and
             radial distortion coefficients.
 
+        Examples:
+            >>> camera_intrinsics.distortion_coefficients
+            DistortionCoefficients(
+                (p1): 5,
+                (k1): 6
+            )
+
         """
         return self._distortion_coefficients
 
@@ -447,6 +677,11 @@ class CameraIntrinsics(ReprMixin):
         Returns:
             A dict containing camera intrinsics.
 
+        Examples:
+            >>> camera_intrinsics.dumps()
+            {'cameraMatrix': {'fx': 1, 'fy': 2, 'cx': 3, 'cy': 4, 'skew': 3},
+            'distortionCoefficients': {'p1': 5, 'k1': 6}}
+
         """
         contents = {"cameraMatrix": self._camera_matrix.dumps()}
         if self._distortion_coefficients:
@@ -454,19 +689,49 @@ class CameraIntrinsics(ReprMixin):
 
         return contents
 
-    def set_camera_matrix(
+    def set_camera_matrix(  # pylint: disable=[too-many-arguments, invalid-name]
         self,
-        matrix: Optional[Sequence[Sequence[float]]] = None,
-        **kwargs: float,
+        fx: Optional[float] = None,
+        fy: Optional[float] = None,
+        cx: Optional[float] = None,
+        cy: Optional[float] = None,
+        skew: float = 0,
+        *,
+        matrix: Optional[MatrixType] = None,
     ) -> None:
         """Set camera matrix of the camera intrinsics.
 
         Arguments:
+            fx: The x axis focal length expressed in pixels.
+            fy: The y axis focal length expressed in pixels.
+            cx: The x coordinate of the so called principal point that should be in the center of
+                the image.
+            cy: The y coordinate of the so called principal point that should be in the center of
+                the image.
+            skew: It causes shear distortion in the projected image.
             matrix: Camera matrix in 3x3 sequence.
-            **kwargs: Contains fx, fy, cx, cy, skew(optional)
+
+        Examples:
+            >>> camera_intrinsics.set_camera_matrix(fx=11, fy=12, cx=13, cy=14, skew=15)
+            >>> camera_intrinsics
+            CameraIntrinsics(
+                (camera_matrix): CameraMatrix(
+                    (fx): 11,
+                    (fy): 12,
+                    (cx): 13,
+                    (cy): 14,
+                    (skew): 15
+                ),
+                (distortion_coefficients): DistortionCoefficients(
+                    (p1): 1,
+                    (p2): 2,
+                    (k1): 3,
+                    (k2): 4
+                )
+            )
 
         """
-        self._camera_matrix = CameraMatrix(matrix=matrix, **kwargs)
+        self._camera_matrix = CameraMatrix(fx, fy, cx, cy, skew, matrix=matrix)
 
     def set_distortion_coefficients(self, **kwargs: float) -> None:
         """Set distortion coefficients of the camera intrinsics.
@@ -474,6 +739,25 @@ class CameraIntrinsics(ReprMixin):
         Arguments:
             **kwargs: Contains p1, p2, ..., k1, k2, ...
 
+        Examples:
+            >>> camera_intrinsics.set_distortion_coefficients(p1=11, p2=12, k1=13, k2=14)
+            >>> camera_intrinsics
+            CameraIntrinsics(
+                (camera_matrix): CameraMatrix(
+                    (fx): 11,
+                    (fy): 12,
+                    (cx): 13,
+                    (cy): 14,
+                    (skew): 15
+                ),
+                (distortion_coefficients): DistortionCoefficients(
+                    (p1): 11,
+                    (p2): 12,
+                    (k1): 13,
+                    (k2): 14
+                )
+            )
+
         """
         self._distortion_coefficients = DistortionCoefficients(**kwargs)
 
@@ -489,6 +773,22 @@ class CameraIntrinsics(ReprMixin):
         Returns:
             The coordinates on the pixel plane where the point is projected to.
 
+        Examples:
+            Project a point with 2 dimensions.
+
+            >>> camera_intrinsics.project((1, 2))
+            Vector2D(137.0, 510.0)
+
+            Project a point with 3 dimensions.
+
+            >>> camera_intrinsics.project((1, 2, 3))
+            Vector2D(6.300411522633745, 13.868312757201647)
+
+            Project a point with 2 dimensions, fisheye is True
+
+            >>> camera_intrinsics.project((1, 2), is_fisheye=True)
+            Vector2D(9.158401093771875, 28.633604375087504)
+
         """
         if self._distortion_coefficients:
             point = self._distortion_coefficients.distort(point, is_fisheye)
