@@ -5,7 +5,7 @@
 
 """Utility classes."""
 
-from .common import EqMixin, common_loads
+from .common import Deprecated, EqMixin, MatrixType, common_loads
 from .name import NameMixin, NameOrderedDict, NameSortedDict, NameSortedList
 from .repr import ReprMixin, ReprType, repr_config
 from .tbrn import TBRN, TBRNType
@@ -13,23 +13,25 @@ from .type import SubcatalogTypeRegister, TypeEnum, TypeMixin, TypeRegister
 from .user import UserMapping, UserMutableMapping, UserMutableSequence, UserSequence
 
 __all__ = [
+    "Deprecated",
     "EqMixin",
+    "MatrixType",
     "NameMixin",
     "NameOrderedDict",
     "NameSortedDict",
     "NameSortedList",
+    "ReprMixin",
+    "ReprType",
+    "SubcatalogTypeRegister",
     "TBRN",
     "TBRNType",
     "TypeEnum",
     "TypeMixin",
     "TypeRegister",
-    "SubcatalogTypeRegister",
-    "UserSequence",
-    "UserMutableSequence",
     "UserMapping",
     "UserMutableMapping",
-    "ReprMixin",
-    "ReprType",
-    "repr_config",
+    "UserMutableSequence",
+    "UserSequence",
     "common_loads",
+    "repr_config",
 ]
